package cn.dankal.test.common.service.aspect;

import org.aspectj.lang.annotation.AfterThrowing;
import org.aspectj.lang.annotation.Around;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * {@link Target,Retention}
 * <p>
 * 此注解标注使用在标有诸如：
 * <br/>
 * - {@link org.springframework.web.bind.annotation.RequestMapping}
 * <br/>
 * - {@link org.springframework.web.bind.annotation.GetMapping}
 * <br/>
 * - {@link org.springframework.web.bind.annotation.PostMapping}
 * <br/>
 * - {@link org.springframework.web.bind.annotation.PutMapping}
 * <br/>
 * - {@link org.springframework.web.bind.annotation.DeleteMapping}
 * </p>
 * 等 SpringMVC 处理器方法注解的方法上 用于记录 请求日志 和 处理请求异常日志
 * <br/>
 * <br/>
 * 当前注解{@link DoRequestLog} 是 Request日志切面${@link RequestLogAspect} 的 切入点表达式
 * <br/>
 * <br/>
 * {@link Around}: 实现 请求日志打印 {@link cn.dankal.test.common.service.aspect.RequestLogAspect.RequestInfo}
 * <br/>
 * <br/>
 * {@link AfterThrowing} : 实现 异常日志打印 {@link cn.dankal.test.common.service.aspect.RequestLogAspect.RequestErrorInfo}
 * <br/>
 * <br/>
 *
 * @author ZGH.MercyModest
 * @version V1.0.0
 * @create 2020/10/19
 * @see RequestLogAspect
 */
@Target({ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
public @interface DoRequestLog {

}
